@@ -1,6 +1,5 @@
 #include "mapper.h"
 #include "dynamic.h"
-#include "servicedef.h"
 
 #include "perl_unpollute.h"
 
@@ -2806,49 +2805,6 @@ void MapperField::set_map(HV *self, SV *ref) {
     SvREFCNT_inc(SvRV(field_ref));
 }
 
-EnumMapper::EnumMapper(pTHX_ Dynamic *_registry, const upb::EnumDef *_enum_def) :
-        registry(_registry),
-        enum_def(_enum_def) {
-    SET_THX_MEMBER;
-
-    registry->ref();
-}
-
-EnumMapper::~EnumMapper() {
-    // make sure this only goes away after inner destructors have completed
-    refcounted_mortalize(aTHX_ registry);
-}
-
-SV *EnumMapper::enum_descriptor() const {
-    SV *ref = newSV(0);
-
-    sv_setref_iv(ref, "Google::ProtocolBuffers::Dynamic::EnumDef", (IV) enum_def);
-
-    return ref;
-}
-
-ServiceMapper::ServiceMapper(pTHX_ Dynamic *_registry, const gpd::ServiceDef *_service_def) :
-        registry(_registry),
-        service_def(_service_def) {
-    SET_THX_MEMBER;
-
-    registry->ref();
-}
-
-ServiceMapper::~ServiceMapper() {
-    delete service_def;
-    // make sure this only goes away after inner destructors have completed
-    refcounted_mortalize(aTHX_ registry);
-}
-
-SV *ServiceMapper::service_descriptor() const {
-    SV *ref = newSV(0);
-
-    sv_setref_iv(ref, "Google::ProtocolBuffers::Dynamic::ServiceDef", (IV) service_def);
-
-    return ref;
-}
-
 MethodMapper::MethodMapper(pTHX_ Dynamic *_registry, const string &method, const MessageDef *_input_def, const MessageDef *_output_def, bool client_streaming, bool server_streaming) :
         registry(_registry),
         input_def(_input_def),
